.. raw:: html

    <embed>
        <p align="center">
            <img width="200" src="https://github.com/yngtodd/segment/blob/master/img/segment_crop.png">
        </p>
    </embed>

--------------------------

.. image:: https://badge.fury.io/py/segment.png
    :target: http://badge.fury.io/py/segment

.. image:: https://travis-ci.org/yngtodd/segment.png?branch=master
    :target: https://travis-ci.org/yngtodd/segment


Segment
-------

Medical imaging segmentation
